"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const globals_1 = require("@jest/globals");
const main_1 = require("./main");
class ConcreteFetchClient extends main_1.AbstractFetchClient {
    constructor() {
        super({ basePath: "", defaultHeaders: {} });
    }
    query(params) {
        return this._query(params);
    }
}
(0, globals_1.describe)("main", () => {
    const client = new ConcreteFetchClient();
    (0, globals_1.describe)("_query", () => {
        it("returns an empty string when all params are undefined", () => {
            (0, globals_1.expect)(client.query({ foo: undefined, bar: undefined })).toBe("");
        });
        it("returns the defined params in a simple case", () => {
            (0, globals_1.expect)(client.query({ foo: undefined, bar: "baz", foobar: "value" })).toBe("?bar=baz&foobar=value");
        });
        it("repeats array params", () => {
            (0, globals_1.expect)(client.query({ foo: ["bar", "baz"] })).toBe("?foo=bar&foo=baz");
        });
        it("handles objects", () => {
            (0, globals_1.expect)(client.query({ foo: { bar: "baz" } })).toBe(`?${encodeURIComponent("foo[bar]")}=baz`);
        });
        it("handles arrays of objects with multiple properties", () => {
            (0, globals_1.expect)(client.query({
                foo: [
                    { prop1: "one", prop2: "two" },
                    { prop1: "foo", prop2: "bar" },
                ],
                limit: 10,
                undefined: undefined,
                includeSomething: false,
            })).toBe(`?${encodeURIComponent("foo[prop1]")}=one&${encodeURIComponent("foo[prop2]")}=two&${encodeURIComponent("foo[prop1]")}=foo&${encodeURIComponent("foo[prop2]")}=bar&limit=10&includeSomething=false`);
        });
    });
});
//# sourceMappingURL=main.spec.js.map